import os
import nmap
from faker import Faker


class Server:

    def __init__(self):
        self.ports = [22, 21, 23, 3389, 3306, 80, 443, 25, 110, 135, 1433, 5632, 5900, 25565]
        self.host = None
        self.valid_ports = []
        self.valid_ips = []
        self.map = nmap.PortScanner()
        if not os.path.exists('invalid.txt'):
            open('invalid.txt', 'w').writelines('')
        if not os.path.exists('valid.txt'):
            open('valid.txt', 'w').writelines('')

    def next(self):
        while True:
            self.host = Faker().ipv4()
            if self.host not in open('invalid.txt', 'r').read() and self.host not in open('valid.txt', 'r').read():
                return self.host

    def save(self, option='valid'):
        with open(f'{option}.txt', 'a') as f:
            if option == 'valid':
                f.writelines(f'{self.host},{",".join(str(p) for p in self.valid_ports)}\n')
            else:
                f.writelines(f'{self.host},')
        f.close()

    def run(self, verbose=False):
        while True:
            self.next()
            try:
                self.map.scan(self.host, arguments=f'-p {",".join(str(port) for port in self.ports)} --open')
                for ports in self.ports:
                    result = self.map[self.host].has_tcp(ports)
                    if result:
                        self.valid_ips.append([self.host, ports])
                self.valid_ports = self.map[self.host]["tcp"].keys()
                print(f'Results {self.host}: {self.map[self.host]["tcp"].keys()}')
                self.save()
            except Exception as e:
                self.save('invalid')
                if verbose:
                    print(f'error: {e}')



from setuptools import setup, find_packages
import os

here = os.path.abspath(os.path.dirname(__file__))

with open('README.md', 'r', encoding="utf-8") as fh:
    long_description = fh.read()

VERSION = '1.0.0'
DESCRIPTION = "ServPy is a Python library that allows you to bruteforce and find (ssh, ftp, windows) server in the internet by checking open ports"
# LONG_DESCRIPTION = 'A package that allows get metadata from websites allowing to perfect your targeting.'

# Setting up
setup(
    name="servpy",
    version=VERSION,
    author="Aymane Elhattab",
    author_email="<aymane.elhattab.master@gmail.com>",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=long_description,
    packages=find_packages(),
    install_requires=['python-nmap', 'faker'],
    keywords=['rdp', 'server', 'port-check', 'bruteforce'],
    classifiers=[
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)